diff src/option.c @ 2269:fb627e94e6c6 vim73

Couple of small fixes for conceal feature. (Dominique Pelle)
author Bram Moolenaar <bram@vim.org>
date Tue, 22 Jun 2010 05:16:38 +0200
parents c08f91142c41
children 2b33a7678e7b
line wrap: on
line diff
--- a/src/option.c
+++ b/src/option.c
@@ -7334,12 +7334,21 @@ set_bool_option(opt_idx, varp, value, op
 #endif
     }
 
 #ifdef FEAT_TITLE
     /* when 'modifiable' is changed, redraw the window title */
     else if ((int *)varp == &curbuf->b_p_ma)
     {
+# ifdef FEAT_TITLE
 	redraw_titles();
-    }
+# endif
+# ifdef FEAT_CONCEAL
+	if (curwin->w_p_conceal)
+	    update_single_line(curwin, curwin->w_cursor.lnum);
+# endif
+    }
+#endif
+#ifdef FEAT_TITLE
     /* when 'endofline' is changed, redraw the window title */
     else if ((int *)varp == &curbuf->b_p_eol)
     {
@@ -8443,7 +8452,7 @@ findoption(arg)
 get_option_value(name, numval, stringval, opt_flags)
     char_u	*name;
     long	*numval;
-    char_u	**stringval;	    /* NULL when only checking existance */
+    char_u	**stringval;	    /* NULL when only checking existence */
     int		opt_flags;
 {
     int		opt_idx;
@@ -7334,12 +7334,21 @@ set_bool_option(opt_idx, varp, value, op
     }
 
-#ifdef FEAT_TITLE
-    /* when 'modifiable' is changed, redraw the window title */
+#if defined(FEAT_TITLE) || defined(FEAT_CONCEAL)
+    /* when 'modifiable' is changed, redraw the window title and
+     * update current line for concealable items */
     else if ((int *)varp == &curbuf->b_p_ma)
     {